# Bluemath {**Toolkit**}

<p align="center">
  <img alt="GitHub Actions" src="https://github.com/GeoOcean/BlueMath_tk/actions/workflows/python-tests.yml/badge.svg?branch=main">
  <img alt="GitHub" src="https://img.shields.io/github/license/GeoOcean/BlueMath_tk">
  <img alt="PyPI" src="https://img.shields.io/pypi/v/BlueMath_tk">
  <img alt="Conda (channel only)" src="https://img.shields.io/conda/vn/conda-forge/BlueMath_tk">
  <img alt="PyPI - Python Version" src="https://img.shields.io/pypi/pyversions/BlueMath_tk">
</p>

Module collection for custom climate data analysis. The main objective of this Python package is to provide a set of statistical tools tailored for climate data analysis, with a focus on statistical classification and prediction.

The package also includes a set of utility functions for processing climate data. To facilitate understanding of how to use these modules, simple demonstration scripts and the necessary data have been added to this repository.

## Installation

```sh
pip install bluemath-tk
```

## License

This project is licensed under the MIT License. See the [license](LICENSE.txt) file for details

## Project status

- UNDER DEVELOPMENT